'use strict';

const vue = require('vue');
const useI18n = require('../shared/vue-intl-controller.be198c5f.cjs');
require('../shared/vue-intl-controller.335464fe.cjs');

/** Represents a value that can be either `T` or an array of `T`. */

function createObject() {
  return Object.create(null);
}
function isObject(value) {
  return value != null && typeof value === 'object';
}
function isPropsWithMessageID(value) {
  return isObject(value) && 'messageId' in value;
}
function isPropsWithMessage(value) {
  return isObject(value) && 'message' in value;
}
function IntlFormatted(props, context) {
  if (!isPropsWithMessageID(props) && !isPropsWithMessage(props)) {
    throw new Error('IntlFormatted cannot be rendered without "message-id" or "message" properties');
  }
  const {
    intl
  } = useI18n.useI18n();

  /** Initial values are passed to the slots. */
  const initialValues = createObject();

  /**
   * Provided values are values that were automatically provided by the
   * IntlFormatted component. They are also used to format the message.
   *
   * Initial values are to be merged before assigning provided values.
   */
  const values = createObject();
  if (props.values != null) {
    Object.assign(initialValues, props.values);
    Object.assign(values, initialValues);
  }
  if (Array.isArray(props.tags)) {
    for (const tag of props.tags) {
      let key;
      let component;
      if (Array.isArray(tag)) {
        key = tag[0];
        component = tag[1];
      } else {
        if (typeof tag !== 'string') {
          throw new TypeError('Custom components must be provided as array of [name, component]');
        }
        key = tag;
        component = tag;
      }
      values[key] = children => {
        const newChildren = [];
        for (const child of children) {
          if (Array.isArray(child)) {
            newChildren.push(...child);
          } else {
            newChildren.push(vue.isVNode(child) ? child : vue.createTextVNode(String(child)));
          }
        }
        if (typeof component === 'string') {
          return [vue.h(component, newChildren)];
        } else {
          return [vue.h(component, newChildren)];
        }
      };
    }
  } else if (props.tags != null) {
    throw new Error('Property "tags" of IntlFormatted needs to be of array type or null / undefined');
  }
  for (const [name, slot] of Object.entries(context.slots)) {
    if (!slot) continue;
    if (name.startsWith('~')) {
      const res = slot({
        values: initialValues
      });
      if (res != null) {
        if (res.length > 1) {
          throw new Error(`Slot argument "${name}" returned more than one child`);
        }
        values[name.slice(1)] = res[0];
      }
    } else {
      values[name] = children => {
        const res = slot({
          children,
          values: initialValues
        });
        if (res != null) {
          if (res.length > 1) {
            throw new Error(`Wrapping slot "${name}" returned more than one child`);
          }
          return res[0];
        }
        return '';
      };
    }
  }
  let formatted;
  if (isPropsWithMessage(props)) {
    formatted = intl.formatters.getMessageFormat(props.message, intl.locale, intl.formats).format(values);
  } else if (props.messageId != null) {
    formatted = intl.formatMessage(typeof props.messageId === 'string' ? {
      id: props.messageId
    } : props.messageId, values);
  } else {
    // Should never end up here, but tell that to TypeScript :\
    throw new Error('Illegal state: neither message nor messageId properties provided');
  }
  return (Array.isArray(formatted) ? formatted.flat() : [formatted]).map(child => {
    return vue.isVNode(child) ? child : vue.createTextVNode(String(child));
  });
}

exports.IntlFormatted = IntlFormatted;
