'use strict';

const IntlController = require('./shared/vue-intl-controller.9b3cf495.cjs');
const ErrorEvent = require('./shared/vue-intl-controller.03b2ffda.cjs');
const consts = require('./shared/vue-intl-controller.335464fe.cjs');
require('@formatjs/intl-localematcher');
require('vue');
require('@formatjs/intl');
require('@braw/async-computed');

/** Represents options for the plugin. */

function createPlugin(opts) {
  let controllerInstance = null;
  function getOrCreateController() {
    if (controllerInstance == null) {
      controllerInstance = IntlController.createController(opts == null ? void 0 : opts.controllerOpts);
    }
    return controllerInstance;
  }
  function getInjections() {
    const controller = getOrCreateController();
    return {
      $fmt: {
        configurable: true,
        get() {
          return controller.formats;
        }
      },
      $t: {
        configurable: true,
        get() {
          return controller.formatMessage;
        }
      },
      $i18n: {
        configurable: true,
        get() {
          return controller;
        }
      }
    };
  }
  return {
    getOrCreateController,
    getInjections,
    toProperties() {
      return Object.defineProperties(ErrorEvent.createHashMap(), getInjections());
    },
    install(app) {
      var _opts$globalMixin, _opts$globalComponent;
      app.provide(consts.controllerKey, getOrCreateController());
      if ((_opts$globalMixin = opts == null ? void 0 : opts.globalMixin) != null ? _opts$globalMixin : true) {
        app.mixin({
          beforeCreate() {
            Object.defineProperties(this, getInjections());
          }
        });
      }
      if ((opts == null ? void 0 : opts.injectInto) != null) {
        const injections = getInjections();
        for (const injectionSite of opts.injectInto) {
          Object.defineProperties(injectionSite, injections);
        }
      }
      if ((_opts$globalComponent = opts == null ? void 0 : opts.globalComponent) != null ? _opts$globalComponent : true) {
        app.component('IntlFormatted', import('./chunks/IntlFormatted.cjs').then(module => module.IntlFormatted));
      }
    }
  };
}

exports.createPlugin = createPlugin;
