import { c as createController } from './shared/vue-intl-controller.87d7f970.mjs';
import { g as createHashMap } from './shared/vue-intl-controller.1850a2eb.mjs';
import { c as controllerKey } from './shared/vue-intl-controller.d1541efa.mjs';
import '@formatjs/intl-localematcher';
import 'vue';
import '@formatjs/intl';
import '@braw/async-computed';

/** Represents options for the plugin. */

function createPlugin(opts) {
  let controllerInstance = null;
  function getOrCreateController() {
    if (controllerInstance == null) {
      controllerInstance = createController(opts == null ? void 0 : opts.controllerOpts);
    }
    return controllerInstance;
  }
  function getInjections() {
    const controller = getOrCreateController();
    return {
      $fmt: {
        configurable: true,
        get() {
          return controller.formats;
        }
      },
      $t: {
        configurable: true,
        get() {
          return controller.formatMessage;
        }
      },
      $i18n: {
        configurable: true,
        get() {
          return controller;
        }
      }
    };
  }
  return {
    getOrCreateController,
    getInjections,
    toProperties() {
      return Object.defineProperties(createHashMap(), getInjections());
    },
    install(app) {
      var _opts$globalMixin, _opts$globalComponent;
      app.provide(controllerKey, getOrCreateController());
      if ((_opts$globalMixin = opts == null ? void 0 : opts.globalMixin) != null ? _opts$globalMixin : true) {
        app.mixin({
          beforeCreate() {
            Object.defineProperties(this, getInjections());
          }
        });
      }
      if ((opts == null ? void 0 : opts.injectInto) != null) {
        const injections = getInjections();
        for (const injectionSite of opts.injectInto) {
          Object.defineProperties(injectionSite, injections);
        }
      }
      if ((_opts$globalComponent = opts == null ? void 0 : opts.globalComponent) != null ? _opts$globalComponent : true) {
        app.component('IntlFormatted', import('./chunks/IntlFormatted.mjs').then(module => module.IntlFormatted));
      }
    }
  };
}

export { createPlugin };
